Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/board_toolkit_simpletest.py
    :caption: examples/board_toolkit_simpletest.py
    :linenos:
